==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/python/Setuptools.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Manages packaging through setuptools with a setup.py script.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.911Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Setuptools")
public class Setuptools extends io.github.cdklabs.projen.Component implements io.github.cdklabs.projen.python.IPythonPackaging {

    protected Setuptools(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Setuptools(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Setuptools(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonProject project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonPackagingOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A task that uploads the package to a package repository.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getPublishTask() {
        return software.amazon.jsii.Kernel.get(this, "publishTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) A task that uploads the package to the Test PyPI repository.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getPublishTestTask() {
        return software.amazon.jsii.Kernel.get(this, "publishTestTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Setuptools}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Setuptools> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.python.PythonProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.python.PythonProject project;
        private final io.github.cdklabs.projen.python.PythonPackagingOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.python.PythonProject project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.python.PythonPackagingOptions.Builder();
        }

        /**
         * (experimental) Author's e-mail.
         * <p>
         * Default: $GIT_USER_EMAIL
         * <p>
         * @return {@code this}
         * @param authorEmail Author's e-mail. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder authorEmail(final java.lang.String authorEmail) {
            this.options.authorEmail(authorEmail);
            return this;
        }

        /**
         * (experimental) Author's name.
         * <p>
         * Default: $GIT_USER_NAME
         * <p>
         * @return {@code this}
         * @param authorName Author's name. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder authorName(final java.lang.String authorName) {
            this.options.authorName(authorName);
            return this;
        }

        /**
         * (experimental) Version of the package.
         * <p>
         * Default: "0.1.0"
         * <p>
         * @return {@code this}
         * @param version Version of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options.version(version);
            return this;
        }

        /**
         * (experimental) A list of PyPI trove classifiers that describe the project.
         * <p>
         * @return {@code this}
         * @see https://pypi.org/classifiers/
         * @param classifiers A list of PyPI trove classifiers that describe the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder classifiers(final java.util.List<java.lang.String> classifiers) {
            this.options.classifiers(classifiers);
            return this;
        }

        /**
         * (experimental) A short description of the package.
         * <p>
         * @return {@code this}
         * @param description A short description of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(final java.lang.String description) {
            this.options.description(description);
            return this;
        }

        /**
         * (experimental) A URL to the website of the project.
         * <p>
         * @return {@code this}
         * @param homepage A URL to the website of the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder homepage(final java.lang.String homepage) {
            this.options.homepage(homepage);
            return this;
        }

        /**
         * (experimental) License of this package as an SPDX identifier.
         * <p>
         * @return {@code this}
         * @param license License of this package as an SPDX identifier. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder license(final java.lang.String license) {
            this.options.license(license);
            return this;
        }

        /**
         * (experimental) Additional options to set for poetry if using poetry.
         * <p>
         * @return {@code this}
         * @param poetryOptions Additional options to set for poetry if using poetry. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder poetryOptions(final io.github.cdklabs.projen.python.PoetryPyprojectOptionsWithoutDeps poetryOptions) {
            this.options.poetryOptions(poetryOptions);
            return this;
        }

        /**
         * (experimental) Additional fields to pass in the setup() function if using setuptools.
         * <p>
         * @return {@code this}
         * @param setupConfig Additional fields to pass in the setup() function if using setuptools. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder setupConfig(final java.util.Map<java.lang.String, ? extends java.lang.Object> setupConfig) {
            this.options.setupConfig(setupConfig);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.python.Setuptools}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Setuptools build() {
            return new io.github.cdklabs.projen.python.Setuptools(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/python/Setuptools.java <==
package io.github.cdklabs.projen.python;

/**
 * (experimental) Manages packaging through setuptools with a setup.py script.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.577Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.python.Setuptools")
public class Setuptools extends io.github.cdklabs.projen.Component implements io.github.cdklabs.projen.python.IPythonPackaging {

    protected Setuptools(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Setuptools(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Setuptools(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.python.PythonPackagingOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) A task that uploads the package to a package repository.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getPublishTask() {
        return software.amazon.jsii.Kernel.get(this, "publishTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) A task that uploads the package to the Test PyPI repository.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getPublishTestTask() {
        return software.amazon.jsii.Kernel.get(this, "publishTestTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.python.Setuptools}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.python.Setuptools> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.python.PythonPackagingOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.python.PythonPackagingOptions.Builder();
        }

        /**
         * (experimental) Author's e-mail.
         * <p>
         * Default: $GIT_USER_EMAIL
         * <p>
         * @return {@code this}
         * @param authorEmail Author's e-mail. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder authorEmail(final java.lang.String authorEmail) {
            this.options.authorEmail(authorEmail);
            return this;
        }

        /**
         * (experimental) Author's name.
         * <p>
         * Default: $GIT_USER_NAME
         * <p>
         * @return {@code this}
         * @param authorName Author's name. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder authorName(final java.lang.String authorName) {
            this.options.authorName(authorName);
            return this;
        }

        /**
         * (experimental) Version of the package.
         * <p>
         * Default: "0.1.0"
         * <p>
         * @return {@code this}
         * @param version Version of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options.version(version);
            return this;
        }

        /**
         * (experimental) A list of PyPI trove classifiers that describe the project.
         * <p>
         * @return {@code this}
         * @see <a href="https://pypi.org/classifiers/">https://pypi.org/classifiers/</a>
         * @param classifiers A list of PyPI trove classifiers that describe the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder classifiers(final java.util.List<java.lang.String> classifiers) {
            this.options.classifiers(classifiers);
            return this;
        }

        /**
         * (experimental) A short description of the package.
         * <p>
         * @return {@code this}
         * @param description A short description of the package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(final java.lang.String description) {
            this.options.description(description);
            return this;
        }

        /**
         * (experimental) A URL to the website of the project.
         * <p>
         * @return {@code this}
         * @param homepage A URL to the website of the project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder homepage(final java.lang.String homepage) {
            this.options.homepage(homepage);
            return this;
        }

        /**
         * (experimental) License of this package as an SPDX identifier.
         * <p>
         * @return {@code this}
         * @param license License of this package as an SPDX identifier. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder license(final java.lang.String license) {
            this.options.license(license);
            return this;
        }

        /**
         * (experimental) Package name.
         * <p>
         * @return {@code this}
         * @param packageName Package name. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder packageName(final java.lang.String packageName) {
            this.options.packageName(packageName);
            return this;
        }

        /**
         * (experimental) Additional options to set for poetry if using poetry.
         * <p>
         * @return {@code this}
         * @param poetryOptions Additional options to set for poetry if using poetry. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder poetryOptions(final io.github.cdklabs.projen.python.PoetryPyprojectOptionsWithoutDeps poetryOptions) {
            this.options.poetryOptions(poetryOptions);
            return this;
        }

        /**
         * (experimental) Additional fields to pass in the setup() function if using setuptools.
         * <p>
         * @return {@code this}
         * @param setupConfig Additional fields to pass in the setup() function if using setuptools. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder setupConfig(final java.util.Map<java.lang.String, ? extends java.lang.Object> setupConfig) {
            this.options.setupConfig(setupConfig);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.python.Setuptools}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.python.Setuptools build() {
            return new io.github.cdklabs.projen.python.Setuptools(
                this.project,
                this.options.build()
            );
        }
    }
}
